# -*- coding: utf-8 -*-
"""
from tempfile import NamedTemporaryFile
"""

import argparse

from .bump import Bump
from .color import ColorUI
from . import __version__

arg_desc = f'''\
===================================
     Bumpster v{__version__}
===================================

usage:
$ bump [options] VERSION_SEGMENT
where VERSION_SEGMENT is:
[major, minor, patch, prerelease, build]
'''


def entry_point():
    """
    The script entrypoint
    """
    parser = argparse.ArgumentParser(
        formatter_class=argparse.RawDescriptionHelpFormatter,
        description=arg_desc,
        prog='bump'
    )

    # The primary argument
    parser.add_argument(
        "part", 
        nargs='?',
        default='build',
        choices=['major', 'minor', 'patch', 'prerelease', 'build'],
        help="what to bump"
    )
    # is_canonical
    parser.add_argument(
        "--canonical", action="store_true",
        help = "True/False is the current pep440 of this version canonical"
    )
    # cfg_file flag
    parser.add_argument(
        '--config_file', 
        action='store', 
        metavar='FILE_NAME',
        type=argparse.FileType('r', encoding='utf-8'),
        help='supply an alternate config file instead of ./.bumpster'
    )
    # current flag
    parser.add_argument(
        '--current', action='store_true',
        help='display the current semantic version'
    )
    # default config
    parser.add_argument(
        "--defaults", action="store_true",
        help = "use default config to run without a config file"
    )
    # dry-run flag
    parser.add_argument(
        "--dry-run", action="store_true",
        help = "dry run - will not modify files - best with --verbose"
    )
    # pep440 flag
    parser.add_argument(
        "--pep440", action="store_true",
        help = "display the current pep440 version"
    )
    # public flag
    parser.add_argument(
        '--public', action='store_true',
        help='display the current public version'
    )
    # verbose flag
    parser.add_argument(
        "--verbose", action="store_true",
        help = "verbose output"
    )
    # version flag
    parser.add_argument('--version', action='version',version=f'bumpster v{__version__}')


    # The meat of the cli, parse the args
    args = vars(parser.parse_args())

    # Main arg
    part = args['part']
    # Flags
    verbose = args['verbose']
    dry_run = args['dry_run']
    defaults = args['defaults']
    config_file = args['config_file']

    current = args['current']
    public = args['public']
    pep440 = args['pep440']
    canonical = args['canonical']

    b = Bump(
        verbose=verbose, 
        dry_run=dry_run, 
        defaults=defaults,
        config_file=config_file
    )

    if current:
        b.print(f'Current: {b.version.semantic}', ColorUI.BLUE)
    elif public:
        b.print(f'Public: {b.version.public}', ColorUI.BLUE)
    elif pep440:
        b.print(f'Pep440: {b.version.pep440}', ColorUI.BLUE)
    elif canonical:
        b.print(
            f'Pep440 (canonical={b.version.is_canonical}): {b.version.pep440}', 
            ColorUI.BLUE
        )
    else:
        b.bump(part.lower())
        b.print(f'Version: {b.version.semantic}', ColorUI.BLUE)



